-- ****************************************************************************
-- *
-- * Licensed Materials - Property of IBM
-- * 5698-WSH
-- *
-- * (C) Copyright IBM Corp. 2005 - 2006.  All Rights Reserved.
-- *		
-- * US Government Users Restricted Rights - Use, duplication or
-- * disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
-- *
-- ****************************************************************************
-- *
-- * Product  : IBM Tivoli Workload Scheduler
-- *
-- * Component: Warehouse Enablement Pack
-- *
-- * File     : aws_migrate_cdw.db2
-- *
-- * Purpose  : migrate the tws components, attributes,
-- *            relationships and measuremnts values
-- *
-- ****************************************************************************
-- 
----------------------------------------------------------------
-- RUN INSTRUCTIONS:
--    1. Open a DB2 command window.
--    2. Connect to TWH_CDW database by using the following command:
--	 db2 connect to twh_cdw user <db_user> using <db_password>
--	 where <db_user>, <db_password> specify datbase user and password
--    2. Enter the following command
--
--       db2 -f aws_migrate_cdw.db2 -t -l output_migratecdw.txt
--
--       Note: aws_migrate_cdw.db2 is the name of this file.
--             output_migratecdw.txt is the output report filename.
--
----------------------------------------------------------------


---------------------------------------
-- Components
---------------------------------------
-- TWS components staging table
declare global temporary table Stg_Comp
(
  Comp_Id               INTEGER      not null,
  Comp_Corr_Val		VARCHAR(254),
  Comp_Nm		VARCHAR(254),
  Comp_Strt_DTTM	TIMESTAMP,
  CompTyp_Cd            VARCHAR(17)  not null
) with replace on commit preserve rows not logged;


insert into session.Stg_Comp
(Comp_Id, Comp_Corr_Val, Comp_Nm, Comp_Strt_DTTM, CompTyp_Cd)
select
	Comp.Comp_Id,
	substr(Comp.Comp_Corr_Val, length('SCHED_ENGINE - ')+1),
	Comp.Comp_Nm,
	Comp_Strt_DTTM,
	Comp.CompTyp_Cd
from
	TWG.Cur_Comp Comp
where
	CompTyp_Cd = 'SCHED_ENGINE'
     or CompTyp_Cd = 'SCHED_WORKSTATION'
     or CompTyp_Cd = 'SCHED_JOB'
     or CompTyp_Cd = 'SCHED_JOBSTREAM';


update TWG.Comp Comp set
  Comp.Comp_Corr_Val = substr(Comp.Comp_Corr_Val, length('SCHED_ENGINE - ')+1),
  Comp.Msrc_Corr_Cd = 'AWS'
where
  exists (select 1
          from session.Stg_Comp StgComp
          where StgComp.Comp_Id = Comp.Comp_Id);


-- add lost relationship with Engine
insert into TWG.CompReln
(Comp_Source_Id, Comp_Target_Id, RelnTyp_Cd,
 CompReln_Strt_DttM, CompReln_End_DttM, Msrc_Corr_Cd)
select
	Source.Comp_Id,
	Target.Comp_Id,
	'PCHILD',
	current timestamp - current timezone,
	'9999-01-01-00.00.00.000000',
	'AWS'
from
	session.Stg_Comp Source,
	session.Stg_Comp Target
where
	Target.CompTyp_Cd = 'SCHED_JOBSTREAM'
    and Source.CompTyp_Cd = 'SCHED_ENGINE'
    and Source.Comp_Nm = Target.Comp_Corr_Val
    and not exists (select 1
                    from TWG.Cur_CompReln Reln
                    where Source.Comp_Id = Reln.Comp_Source_Id
                      and Target.Comp_Id = Reln.Comp_Target_Id
                      and Reln.RelnTyp_Cd='PCHILD');


-- engine
-- engine staging tables
declare global temporary table Stg_Engine
(
  Comp_Id               INTEGER,
  Comp_Nm		VARCHAR(254),
  Domain_Name		VARCHAR(254),
  Comp_Strt_DTTM	TIMESTAMP,
  Is_Master		VARCHAR(1)
) with replace on commit preserve rows not logged;

declare global temporary table Stg_EngineAttr
(
  CompAttr_Id		INTEGER,
  Comp_Id               INTEGER,
  Attrtyp_Cd		VARCHAR(254),
  Compattr_Val		VARCHAR(254)
) with replace on commit preserve rows not logged;

insert into session.Stg_EngineAttr
(CompAttr_Id, Comp_Id, Attrtyp_Cd, Compattr_Val)
select
	Attr.CompAttr_Id,
	Attr.Comp_Id,
	Attr.Attrtyp_Cd,
	Attr.Compattr_Val
from
	session.Stg_Comp Comp,
	TWG.Cur_CompAttr Attr
where
	Comp.Comp_Id = Attr.Comp_Id
    and Attr.Attrtyp_Cd in ('SCHED_WRKST_TYPE', 'SCHED_DOMAIN');


insert into session.Stg_Engine
(Comp_Id, Comp_Nm, Domain_Name, Comp_Strt_DTTM, Is_Master)
select distinct
	Engine.Comp_Id,
	Engine.Comp_Nm,
	Domain.Compattr_Val,
	Engine.Comp_Strt_DTTM,
	case WrkstType.Compattr_Val
	when '2' then 'Y'
	else 'N'
	end
from
	session.Stg_Comp Engine,
	session.Stg_Comp Workstation,
	session.Stg_EngineAttr WrkstType,
	session.Stg_EngineAttr Domain
where
	Engine.CompTyp_Cd = 'SCHED_ENGINE'
    and Workstation.CompTyp_Cd = 'SCHED_WORKSTATION'
    and Workstation.Comp_Nm = Engine.Comp_Nm
    and Workstation.Comp_Id = Domain.Comp_Id
    and Workstation.Comp_Id = WrkstType.Comp_Id
    and Domain.Attrtyp_Cd = 'SCHED_DOMAIN'
    and WrkstType.Attrtyp_Cd = 'SCHED_WRKST_TYPE';

declare global temporary table Stg_RightEngine
(
  Comp_Id		INTEGER,
  Domain_Name		VARCHAR(254)
) with replace on commit preserve rows not logged;

declare global temporary table Stg_OneEngine
(
  Comp_Id		INTEGER,
  Comp_Nm		VARCHAR(254)
) with replace on commit preserve rows not logged;

insert into session.Stg_OneEngine
(Comp_Id, Comp_Nm)
select
	max(Engine.Comp_Id),
	Engine.Comp_Nm
from
	session.Stg_Engine Engine
where
	Engine.Is_Master = 'Y'
group by
	Engine.Comp_Nm;

insert into session.Stg_RightEngine
(Comp_Id, Domain_Name)
select
	max(Engine.Comp_Id),
	Engine.Domain_Name
from
	session.Stg_Engine Engine,
	session.Stg_OneEngine OneEngine
where
	Engine.Comp_Id = OneEngine.Comp_Id
group by
	Engine.Domain_Name;

-- eliminate multiple engine of domain from session table
update session.Stg_Engine Engine set
  Engine.Is_Master = 'N'
where
  Engine.Is_Master = 'Y'
  and not exists (select 1
                  from session.Stg_RightEngine RightEngine
                  where Engine.Comp_Id = RightEngine.Comp_Id);

-- add right comp corr val
update TWG.Comp Comp set
  Comp.Comp_Corr_Val = (select distinct Stg_Engine.Domain_Name
                        from session.Stg_Engine Stg_Engine
                        where Stg_Engine.Comp_Id = Comp.Comp_Id)
where
  exists (select 1
          from session.Stg_Engine StgEngine
          where StgEngine.Comp_Id = Comp.Comp_Id
            and StgEngine.Is_Master = 'Y');

-- add attribute SCHED_DOMAIN to Engine
insert into TWG.CompAttr
(Comp_Id, AttrTyp_Cd, CompAttr_Strt_DtTm, Compattr_End_Dttm,
 CompAttr_Val, Msrc_Corr_Cd)
select distinct
    Comp.Comp_Id,
    'SCHED_DOMAIN',
    Comp.Comp_Strt_DTTM,
    '9999-01-01-00.00.00.000000',
    Comp.Domain_Name,
    'AWS'
from
    session.Stg_Engine Comp
where
	Comp.Is_Master = 'Y';


-- general pourpose engine temporary table
declare global temporary table Tmp_Engine
(
  Comp_Id_OLD		INTEGER,
  Comp_Nm_OLD		VARCHAR(254),
  Comp_Id_NEW		INTEGER,
  Comp_Nm_NEW		VARCHAR(254),
  Is_Master_OLD		VARCHAR(1)
) with replace on commit preserve rows not logged;

--insert into session.Tmp_Engine
insert into session.Tmp_Engine
(Comp_Id_OLD, Comp_Nm_OLD, Comp_Id_NEW, Comp_Nm_NEW, Is_Master_OLD)
select
	Old.Comp_Id,
	Old.Comp_Nm,
	New.Comp_Id,
	New.Comp_Nm,
	Old.Is_Master
from
    session.Stg_Engine Old,
    session.Stg_Engine New
where
      New.Domain_Name = Old.Domain_Name
  and New.Is_Master = 'Y';



-- workstation
update TWG.Comp Comp set
  Comp.Comp_Corr_Val = 
   concat((select TmpEngine.Comp_Nm_NEW
           from session.Tmp_Engine TmpEngine
           where exists (select 1
                         from TWG.Cur_CompReln Reln
                         where Reln.RelnTyp_Cd = 'PCHILD'
                          and Reln.Comp_Source_Id = Comp_Id_OLD
                          and Reln.Comp_Target_Id = Comp.Comp_Id)),
          concat('#',substr(Comp.Comp_Corr_Val,locate(' ,IP_HOST - ',Comp.Comp_Corr_Val)+length(' ,IP_HOST - '))))
where
  exists (select 1
          from session.Stg_Comp StgComp
          where StgComp.Comp_Id = Comp.Comp_Id
            and StgComp.CompTyp_Cd = 'SCHED_WORKSTATION');


-- add attribute SCHED_HOST_NAME to workstation
insert into TWG.CompAttr
(Comp_Id, AttrTyp_Cd, CompAttr_Strt_DtTm, Compattr_End_Dttm,
 CompAttr_Val, Msrc_Corr_Cd)
select distinct
    Comp.Comp_Id,
    'SCHED_HOST_NAME',
    Comp.Comp_Strt_DTTM,
    '9999-01-01-00.00.00.000000',
    Comp.Comp_Nm,
    'AWS'
from
    session.Stg_Comp Comp
where
    Comp.CompTyp_Cd = 'SCHED_WORKSTATION';


-- job stream
declare global temporary table Temp_Reln_JsWork
(
  Jobstream_Comp_Id     INTEGER      not null,
  Jobstream_Corr_Val	VARCHAR(254),
  Workstation_Comp_Id   INTEGER      not null
) with replace on commit preserve rows not logged;

insert into session.Temp_Reln_JsWork
(Jobstream_Comp_Id, Jobstream_Corr_Val, Workstation_Comp_Id)
select
	Jobstream.Comp_Id,
	Jobstream.Comp_Corr_Val,
	min(Workstation.Comp_Id)
from
	session.Stg_Comp Jobstream,
	session.Stg_Comp Workstation,
	session.Stg_Comp Job,
	TWG.Cur_CompReln RelnJobJobs,
	TWG.Cur_CompReln RelnJobWork
where
	Jobstream.CompTyp_Cd = 'SCHED_JOBSTREAM'
    and Workstation.CompTyp_Cd = 'SCHED_WORKSTATION'
    and Job.CompTyp_Cd = 'SCHED_JOB'
    and RelnJobJobs.RelnTyp_Cd = 'LCONT'
    and RelnJobJobs.Comp_Source_Id = Job.Comp_Id
    and RelnJobJobs.Comp_Target_Id = Jobstream.Comp_Id
    and RelnJobWork.RelnTyp_Cd = 'RUNSON'
    and RelnJobWork.Comp_Source_Id = Job.Comp_Id
    and RelnJobWork.Comp_Target_Id = Workstation.Comp_Id
group by
	Jobstream.Comp_Id,
	Jobstream.Comp_Corr_Val;

declare global temporary table Temp_Jobstream
(
  Jobstream_Comp_Id     INTEGER      not null,
  Workstation_Comp_Id   INTEGER      not null
) with replace on commit preserve rows not logged;

insert into session.Temp_Jobstream
(Jobstream_Comp_Id, Workstation_Comp_Id)
select
	Temp.Jobstream_Comp_Id,
	coalesce ((select Workstation.Comp_Id
	           from session.Stg_Comp Workstation
	           where Workstation.CompTyp_Cd = 'SCHED_WORKSTATION'
                     and Workstation.Comp_Nm = Temp.Jobstream_Corr_Val),
                   Temp.Workstation_Comp_Id)
from
	session.Temp_Reln_JsWork Temp
union
select
	Jobstream.Comp_Id,
	Workstation.Comp_Id
from
	session.Stg_Comp Jobstream,
	session.Stg_Comp Workstation
where
	Workstation.CompTyp_Cd = 'SCHED_WORKSTATION'
    and Workstation.Comp_Nm = Jobstream.Comp_Corr_Val
    and not exists (select 1
	            from session.Temp_Reln_JsWork Temp
	            where Jobstream.Comp_Id = Temp.Jobstream_Comp_Id);


update TWG.Comp Comp set
Comp.Comp_Corr_Val =
 (select concat(TmpEngine.Comp_Nm_NEW,
  concat('#',
          coalesce((select Work.Comp_Nm
                    from session.Temp_Jobstream Temp,
                         session.Stg_Comp Work
                    where Comp.Comp_Id = Temp.Jobstream_Comp_Id
                      and Work.Comp_Id = Temp.Workstation_Comp_Id),
                      TmpEngine.Comp_Nm_NEW)
                      ))
  from session.Tmp_Engine TmpEngine
  where exists (select 1 from TWG.Cur_CompReln Reln
                         where Reln.RelnTyp_Cd = 'PCHILD'
                          and Reln.Comp_Source_Id = TmpEngine.Comp_Id_OLD
                          and Reln.Comp_Target_Id = Comp.Comp_Id))      
where
  exists (select 1
          from session.Stg_Comp StgComp
          where StgComp.Comp_Id = Comp.Comp_Id
            and StgComp.CompTyp_Cd = 'SCHED_JOBSTREAM');



-- job
update TWG.Comp Comp set
  Comp.Comp_Corr_Val =
   concat(coalesce((select Jobstream.Comp_Corr_Val
                    from TWG.Cur_Comp Jobstream
                    where Jobstream.CompTyp_Cd = 'SCHED_JOBSTREAM'
                      and exists (select 1
                                  from TWG.Cur_CompReln Reln
                                  where Reln.RelnTyp_Cd = 'LCONT'
                                    and Reln.Comp_Source_Id = Comp.Comp_Id
                                    and Reln.Comp_Target_Id = Jobstream.Comp_Id)),
                   (select concat(TmpEngine.Comp_Nm_NEW, '##')
                    from session.Tmp_Engine TmpEngine
                    where exists (select 1
                                  from TWG.Cur_CompReln Reln
                                  where Reln.RelnTyp_Cd = 'PCHILD'
                                  and Reln.Comp_Source_Id = Comp_Id_OLD
                                  and Reln.Comp_Target_Id = Comp.Comp_Id))),
          concat('#',substr(Comp.Comp_Corr_Val,locate(' ,SCHED_WORKSTATION - ',Comp.Comp_Corr_Val)+length(' ,SCHED_WORKSTATION - '),locate(' ,SCHED_JOBSTREAM - ',Comp.Comp_Corr_Val)-locate(' ,SCHED_WORKSTATION - ',Comp.Comp_Corr_Val)-length(' ,SCHED_WORKSTATION - '))))
where
  exists (select 1
          from session.Stg_Comp StgComp
          where StgComp.Comp_Id = Comp.Comp_Id
            and StgComp.CompTyp_Cd = 'SCHED_JOB');



-- host
-- temporary tables
declare global temporary table Temp_Comp_Host
(
  Comp_Id               INTEGER      not null,
  Comp_Nm               VARCHAR(254) not null
) with replace on commit preserve rows not logged;

insert into session.Temp_Comp_Host
(Comp_Id, Comp_Nm)
select distinct
	Host.Comp_Id,
	Host.Comp_Nm
from
	TWG.Cur_Comp Host,
	TWG.Cur_CompReln CompReln,
	session.Stg_Comp Workstation
where
	Host.CompTyp_Cd = 'IP_HOST'
   and Workstation.CompTyp_Cd = 'SCHED_WORKSTATION'
   and CompReln.RelnTyp_Cd = 'RUNSON'
   and CompReln.Comp_Source_Id = Workstation.Comp_Id
   and CompReln.Comp_Target_Id = Host.Comp_Id;

insert into TWG.Comp
(Comptyp_Cd, Centr_Cd, Cust_Id, Comp_Nm, Comp_Corr_Val,
 Comp_Strt_Dttm, Comp_End_Dttm, Comp_Ds, MSrc_Corr_Cd)
select
        'SCHED_HOST',
        Centr.Centr_Cd,
        Cust.Cust_Id,
        Host.Comp_Nm,
        '',
        current timestamp - current timezone,
        '9999-01-01-00.00.00.000000',
        'Host',
        'AWS'
from
        session.Temp_Comp_Host Host,
        Aws.Cust_Lookup Cust,
	Aws.Centr_Lookup Centr
where
        Centr.Centr_Cd = 'CDW'
    and Cust.Cust_Id = 1;


---------------------------------------
-- Relationships
---------------------------------------
-- add reln job stream - work
insert into TWG.CompReln
(Comp_Source_Id, Comp_Target_Id, RelnTyp_Cd,
 CompReln_Strt_Dttm, CompReln_End_Dttm, MSrc_Corr_Cd)
select
  Temp.Jobstream_Comp_Id,
  Temp.Workstation_Comp_Id,
  'RUNSON',
  current timestamp - current timezone,
  '9999-01-01-00.00.00.000000',
  'AWS'
from session.Temp_Jobstream Temp;

-- add reln work - sched host
declare global temporary table Temp_Reln_WorkHost
(
  CompReln_Id           INTEGER      not null,
  Workstation_Id        INTEGER      not null,
  Host_Comp_Nm          VARCHAR(254)
) with replace on commit preserve rows not logged;

insert into session.Temp_Reln_WorkHost
(CompReln_Id, Workstation_Id, Host_Comp_Nm)
select
   CompReln.CompReln_Id,
   Workstation.Comp_Id,
   Host.Comp_Nm
from
   TWG.Cur_CompReln CompReln,
   session.Stg_Comp Workstation,
   session.Temp_Comp_Host Host
where
      CompReln.RelnTyp_Cd = 'RUNSON'
  and Workstation.CompTyp_Cd = 'SCHED_WORKSTATION'
  and Workstation.Comp_Id = CompReln.Comp_Source_Id
  and Host.Comp_Id = CompReln.Comp_Target_Id;


-- old reln host
update TWG.CompReln CompReln set 
CompReln.CompReln_End_Dttm = current timestamp - current timezone
where
  exists (select 1
          from session.Temp_Reln_WorkHost Temp_Reln
          where Temp_Reln.CompReln_Id = CompReln.CompReln_Id);

-- add reln work - sched host
insert into TWG.CompReln
(Comp_Source_Id, Comp_Target_Id, RelnTyp_Cd,
 CompReln_Strt_Dttm, CompReln_End_Dttm, MSrc_Corr_Cd)
select
  Temp_Reln.Workstation_Id,
  Host.Comp_Id,
  'RUNSON',
  current timestamp - current timezone,
  '9999-01-01-00.00.00.000000',
  'AWS'
from
  session.Temp_Reln_WorkHost Temp_Reln,
  TWG.Comp Host
where
      Host.CompTyp_Cd = 'SCHED_HOST'
  and Host.Comp_Nm = Temp_Reln.Host_Comp_Nm;


declare global temporary table Temp_CompReln
(
  CompReln_Id           INTEGER      not null
) with replace on commit preserve rows not logged;


insert into session.Temp_CompReln
(CompReln_Id)
select
	CompReln.CompReln_Id
from
	TWG.Cur_CompReln CompReln,
	session.Stg_Comp Source,
	session.Stg_Comp Target
where
	CompReln.RelnTyp_Cd in ('PCHILD', 'LCONT', 'RUNSON')
    and CompReln.Comp_Source_Id = Source.Comp_Id
    and CompReln.Comp_Target_Id = Target.Comp_Id;

-- old reln
update TWG.CompReln CompReln set 
  CompReln.Msrc_Corr_Cd = 'AWS'
where
      exists (select 1
              from session.Temp_CompReln TempCompReln
              where TempCompReln.CompReln_Id = CompReln.CompReln_Id);

-- new relationship for the right engine
insert into TWG.CompReln
(Comp_Source_Id, Comp_Target_Id, RelnTyp_Cd,
 CompReln_Strt_Dttm, CompReln_End_Dttm, MSrc_Corr_Cd)
select
	TmpEngine.Comp_Id_NEW,
	Reln.Comp_Target_Id,
	Reln.RelnTyp_Cd,
	current timestamp - current timezone,
	'9999-01-01-00.00.00.000000',
	'AWS'
from
	session.Tmp_Engine TmpEngine,
	session.Stg_Comp Comp,
	TWG.Cur_CompReln Reln
where
	Comp.CompTyp_Cd = 'SCHED_ENGINE'
    and Comp.Comp_Id = Reln.Comp_Source_Id
    and Comp.Comp_Id = TmpEngine.Comp_Id_OLD
    and TmpEngine.Is_Master_OLD = 'N';

-- eliminate engine not valid
update TWG.Comp Comp set
  Comp.Comp_End_DTTM = current timestamp - current timezone
where
  exists (select 1
          from session.Stg_Engine StgEngine
          where StgEngine.Comp_Id = Comp.Comp_Id
            and StgEngine.Is_Master = 'N');

---------------------------------------
-- Attributes
---------------------------------------
-- TWS attributes staging table
declare global temporary table Temp_CompAttr
(
  CompAttr_Id           INTEGER,
  AttrTyp_Cd            VARCHAR(17),
  CompAttr_Val          VARCHAR(254)
) with replace on commit preserve rows not logged;

insert into session.Temp_CompAttr
(CompAttr_Id, AttrTyp_Cd, CompAttr_Val)
select
	CompAttr.CompAttr_Id,
	CompAttr.AttrTyp_Cd,
	CompAttr.CompAttr_Val
from
	TWG.Cur_CompAttr CompAttr,
	session.Stg_Comp Comp
where
	CompAttr.Comp_Id = Comp.Comp_Id
    and (CompAttr.AttrTyp_Cd = 'SCHED_WRKST_TYPE' or
         CompAttr.AttrTyp_Cd = 'OS_NAME' or
         CompAttr.AttrTyp_Cd = 'SCHED_DOMAIN' or
         CompAttr.AttrTyp_Cd = 'SCHED_PRIORITY' or
         CompAttr.AttrTyp_Cd = 'SCHED_LOGIN' or
         CompAttr.AttrTyp_Cd = 'SCHED_COMMAND');

-- Msrc_Corr_Cd
update TWG.Compattr CompAttr set
CompAttr.Msrc_Corr_Cd = 'AWS'
where
      exists (select 1
              from session.Temp_CompAttr TempCompAttr
              where TempCompAttr.CompAttr_Id = CompAttr.CompAttr_Id);

-- CompAttr_Val 'SCHED_WRKST_TYPE'
update TWG.Compattr CompAttr set
CompAttr.CompAttr_Val = (case CompAttr.CompAttr_Val
                          when '1' then 'Domain Manager'
                          when '2' then 'Master'
                          when '3' then 'Host'
                          when '4' then 'X-Agent'
                          when '5' then 'Standard Agent'
                          when '6' then 'Fault Tolerant Agent'
                          else '-'
                         end)
where
      CompAttr.AttrTyp_Cd = 'SCHED_WRKST_TYPE'
  and exists (select 1
              from session.Temp_CompAttr TempCompAttr
              where TempCompAttr.CompAttr_Id = CompAttr.CompAttr_Id);

-- CompAttr_Val 'OS_NAME'
update TWG.Compattr CompAttr set
CompAttr.CompAttr_Val = (case CompAttr.CompAttr_Val
                          when 'WNT' then 'Windows'
                          when 'UNIX' then 'Unix'
                          when 'OTHR' then 'Other'
                          else 'Other'
                         end)
where
      CompAttr.AttrTyp_Cd = 'OS_NAME'
  and exists (select 1
              from session.Temp_CompAttr TempCompAttr
              where TempCompAttr.CompAttr_Id = CompAttr.CompAttr_Id);




---------------------------------------
-- Measurements
---------------------------------------
-- TWS attributes staging table
declare global temporary table Temp_Msmt
(
  Msmt_Id               INTEGER,
  MsmtTyp_Id            INTEGER
) with replace on commit preserve rows not logged;

insert into session.Temp_Msmt
(Msmt_Id, MsmtTyp_Id)
select
	Msmt.Msmt_Id,
	Msmt.MsmtTyp_Id
from
	TWG.Msmt Msmt,
	session.Stg_Comp Comp
where
	Msmt.Comp_Id = Comp.Comp_Id
    and (CompTyp_Cd = 'SCHED_JOB' or
         CompTyp_Cd = 'SCHED_JOBSTREAM');

-- Msrc_Corr_Cd
update TWG.Msmt Msmt set
Msmt.Msrc_Corr_Cd = 'AWS'
where
      exists (select 1
              from session.Temp_Msmt TempMsmt
              where TempMsmt.Msmt_Id = Msmt.Msmt_Id);

-- Max Min
update TWG.Msmt Msmt set
Msmt.Msmt_Min_Val = Msmt.Msmt_Avg_Val,
Msmt.Msmt_Max_Val = Msmt.Msmt_Avg_Val
where
      exists (select 1
              from session.Temp_Msmt TempMsmt
              where TempMsmt.Msmt_Id = Msmt.Msmt_Id
                and TempMsmt.MsmtTyp_Id in (select MsmtTyp.MsmtTyp_Id
                                            from TWG.MsmtTyp MsmtTyp
                                            where MsmtTyp.MsmtTyp_Nm in
                                                  ('Duration', 'Start Delay',
                                                   'CPU Time')));


-- done.
