-- ****************************************************************************
-- *
-- * Licensed Materials - Property of IBM
-- * 5698-WSH
-- *
-- * (C) Copyright IBM Corp. 2005 - 2006.  All Rights Reserved.
-- *		
-- * US Government Users Restricted Rights - Use, duplication or
-- * disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
-- *
-- ****************************************************************************
-- *
-- * Product  : IBM Tivoli Workload Scheduler
-- *
-- * Component: Warehouse Enablement Pack
-- *
-- * File     : aws_update_start_delay.db2
-- *
-- * Purpose  : update the msmt values for start delay
-- *
-- ****************************************************************************

----------------------------------------------------------------
-- RUN INSTRUCTIONS:
--    1. Open a DB2 command window.
--    2. Connect to TWH_CDW database by using the following command:
--	 db2 connect to twh_cdw user <db_user> using <db_password>
--	 where <db_user>, <db_password> specify datbase user and password
--    2. Enter the following command
--
--       db2 -f aws_update_start_delay_cdw.db2 -t -l output_startdelaycdw.txt
--
--       Note: aws_update_start_delay_cdw.db2 is the name of this file.
--             output_startdelaycdw.txt is the output report filename.
--
----------------------------------------------------------------


declare global temporary table Temp_Comp
(
       Comp_Id              INTEGER not null,
       CompTyp_Cd           CHAR(17) not null
) with replace on commit preserve rows not logged;


insert into session.Temp_Comp
(Comp_Id, CompTyp_Cd)
select
	Comp_Id,
	CompTyp_Cd
from
	Twg.Cur_Comp
where
	CompTyp_Cd = 'SCHED_ENGINE'
     or CompTyp_Cd = 'SCHED_WORKSTATION'
     or CompTyp_Cd = 'SCHED_JOB'
     or CompTyp_Cd = 'SCHED_JOBSTREAM';


declare global temporary table Stg_Temp
(
       Comp_Id              INTEGER not null,
       MsmtTyp_Id           INTEGER not null,
       TmSum_Cd             CHAR(1) not null
) with replace on commit preserve rows not logged;


insert into session.Stg_Temp
(Comp_Id, MsmtTyp_Id, TmSum_Cd)
select
	Comp.Comp_Id, MsmtTyp.MsmtTyp_Id, 'D'
from
	 session.Temp_Comp Comp, Twg.MsmtRul MsmtRul, Twg.MsmtTyp MsmtTyp
where   MsmtTyp.MsmtTyp_Id = MsmtRul.MsmtTyp_Id
    and MsmtRul.CompTyp_Cd = Comp.CompTyp_Cd
    and MsmtTyp.MsmtTyp_Nm = 'Start Delay';

declare global temporary table Temp_Msmt
(
       Msmt_Id           INTEGER not null
) with replace on commit preserve rows not logged;


insert into session.Temp_Msmt
(Msmt_Id)
select
	Msmt.Msmt_Id
from
	 session.Stg_Temp Temp, Twg.Msmt Msmt
where   Msmt.Comp_Id = Temp.Comp_Id
and Msmt.MsmtTyp_Id = Temp.MsmtTyp_Id
and Msmt.TmSum_Cd = Temp.TmSum_Cd;

update Twg.Msmt Msmt set
Msmt_Avg_Val = 
31536000*integer(Msmt.Msmt_Avg_Val/10000000000) + 
case char(length(rtrim(char(integer(Msmt.Msmt_Avg_Val/100000000))))) when '1' then 2592000*integer(Msmt.Msmt_Avg_Val/100000000) else 2592000*integer(substr(rtrim(char(integer(Msmt.Msmt_Avg_Val/100000000))),length(rtrim(char(integer(Msmt.Msmt_Avg_Val/100000000))))-1,2)) end + 
case char(length(rtrim(char(integer(Msmt.Msmt_Avg_Val/1000000))))) when '1' then 86400*integer(Msmt.Msmt_Avg_Val/1000000) else 86400*integer(substr(rtrim(char(integer(Msmt.Msmt_Avg_Val/1000000))),length(rtrim(char(integer(Msmt.Msmt_Avg_Val/1000000))))-1,2)) end +
case char(length(rtrim(char(integer(Msmt.Msmt_Avg_Val/10000))))) when '1' then 3600*integer(Msmt.Msmt_Avg_Val/10000) else 3600*integer(substr(rtrim(char(integer(Msmt.Msmt_Avg_Val/10000))),length(rtrim(char(integer(Msmt.Msmt_Avg_Val/10000))))-1,2)) end +
case char(length(rtrim(char(integer(Msmt.Msmt_Avg_Val/100))))) when '1' then 60*integer(Msmt.Msmt_Avg_Val/100) else 60*integer(substr(rtrim(char(integer(Msmt.Msmt_Avg_Val/100))),length(rtrim(char(integer(Msmt.Msmt_Avg_Val/100))))-1,2)) end +
case char(length(rtrim(char(integer(Msmt.Msmt_Avg_Val))))) when '1' then integer(Msmt.Msmt_Avg_Val) else integer(substr(rtrim(char(integer(Msmt.Msmt_Avg_Val))),length(rtrim(char(integer(Msmt.Msmt_Avg_Val))))-1,2)) end
where exists (select 1
              from session.Temp_Msmt Temp
              where Temp.Msmt_Id = Msmt.Msmt_Id
                and Msmt_Avg_Val != 0);


-- done.